@@ -21,7 +21,7 @@
 
 #include "ispdb.h"
 
-class AutoconfigKolabMail :  public Ispdb
+class AutoconfigKolabMail : public Ispdb
 {
     Q_OBJECT
 public:
@@ -30,7 +30,7 @@ public:
 
     void startJob(const QUrl &url) override;
 
-private Q_SLOTS:
+private:
     void slotResult(KJob *);
 };
 
